@@ -1,4 +1,4 @@
-//@line 42 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.ELsmp_Depend/mozilla/browser/base/content/pageInfo.js"
+//@line 42 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/base/content/pageInfo.js"
 
 //******** define a js object to implement nsITreeView
 function pageInfoTreeView(columnids, copycol)
@@ -182,6 +182,8 @@ const nsIEmbedElement    = Components.interfaces.nsIDOMHTMLEmbedElement
 const nsIButtonElement   = Components.interfaces.nsIDOMHTMLButtonElement
 const nsISelectElement   = Components.interfaces.nsIDOMHTMLSelectElement
 const nsITextareaElement = Components.interfaces.nsIDOMHTMLTextAreaElement
+const nsIQuoteElement    = Components.interfaces.nsIDOMHTMLQuoteElement
+const nsIModElement      = Components.interfaces.nsIDOMHTMLModElement
 
 // Interface for image loading content
 const nsIImageLoadingContent = Components.interfaces.nsIImageLoadingContent;
@@ -227,6 +229,8 @@ function onLoadPageInfo()
   gStrings.linkStylesheet = theBundle.getString("linkStylesheet");
   gStrings.linkRev = theBundle.getString("linkRev");
   gStrings.linkX = theBundle.getString("linkX");
+  gStrings.linkQuote = theBundle.getString("linkQuote");
+  gStrings.linkMod = theBundle.getString("linkMod");
   gStrings.mediaImg = theBundle.getString("mediaImg");
   gStrings.mediaBGImg = theBundle.getString("mediaBGImg");
   gStrings.mediaApplet = theBundle.getString("mediaApplet");
@@ -236,7 +240,8 @@ function onLoadPageInfo()
   gStrings.mediaInput = theBundle.getString("mediaInput");
 
   var docTitle = "";
-  if ("arguments" in window && window.arguments.length >= 1 && window.arguments[0] && window.arguments[0].doc)
+  if ("arguments" in window && window.arguments.length >= 1 &&
+       window.arguments[0] && window.arguments[0].doc)
   {
     theWindow = null;
     theDocument = window.arguments[0].doc;
@@ -271,7 +276,8 @@ function onLoadPageInfo()
 
   /* Select the requested tab, if the name is specified */
   var tabControl = document.getElementById("tabbox");
-  if ("arguments" in window && window.arguments.length >= 1 && window.arguments[0] && window.arguments[0].initialTab)
+  if ("arguments" in window && window.arguments.length >= 1 &&
+       window.arguments[0] && window.arguments[0].initialTab)
   {
     var tab = document.getElementById(window.arguments[0].initialTab);
     if (tab)
@@ -492,6 +498,10 @@ function grabAll(elem)
     addImage(elem.src, gStrings.mediaImg, (elem.hasAttribute("alt")) ? elem.alt : gStrings.notSet, elem, false);
   else if (elem instanceof nsIAreaElement)
     linkView.addRow([elem.alt, elem.href, gStrings.linkArea, elem.target]);
+  else if (elem instanceof nsIQuoteElement && elem.cite)
+    linkView.addRow([getValueText(elem), elem.cite, gStrings.linkQuote]);
+  else if (elem instanceof nsIModElement && elem.cite)
+    linkView.addRow([getValueText(elem), elem.cite, gStrings.linkMod]);
   else if (elem instanceof nsILinkElement)
   {
     if (elem.rel)
@@ -540,13 +550,18 @@ function grabAll(elem)
     addImage(elem.data, gStrings.mediaObject, getValueText(elem), elem, false);
   else if (elem instanceof nsIEmbedElement)
     addImage(elem.src, gStrings.mediaEmbed, "", elem, false);
-  else
-    if (elem.hasAttributeNS(XLinkNS, "href"))
-      linkView.addRow([getValueText(elem),
-                       ioService.newURI(elem.getAttributeNS(XLinkNS, "href"), null, elem.baseURI).spec,
-                       gStrings.linkX,
-                       ""]);
-
+  else if (elem.hasAttributeNS(XLinkNS, "href")) {
+    var ioService = Components.classes["@mozilla.org/network/io-service;1"]
+                              .getService(Components.interfaces.nsIIOService);
+    var href = elem.getAttributeNS(XLinkNS, "href");
+    try {
+      var baseURI = ioService.newURI(elem.baseURI,
+                                     elem.ownerDocument.characterSet, null);
+      var uri = ioService.newURI(href, elem.ownerDocument.characterSet,
+                                 baseURI).spec;
+    } catch (e) {}
+    linkView.addRow([getValueText(elem), uri, gStrings.linkX, ""]);
+  }
   return NodeFilter.FILTER_ACCEPT;
 }
 
