@@ -1,12 +1,12 @@
-//@line 38 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/preferences/feeds.js"
+//@line 38 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/preferences/feeds.js"
 
-//@line 40 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/preferences/feeds.js"
+//@line 40 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/preferences/feeds.js"
 var Cc = Components.classes;
 var Ci = Components.interfaces;
 var Cr = Components.results;
 var TYPE_MAYBE_FEED = "application/vnd.mozilla.maybe.feed";
 const kXULNS = "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";
-//@line 46 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/preferences/feeds.js"
+//@line 46 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/preferences/feeds.js"
 
 /*
  * Preferences:
@@ -103,7 +103,7 @@ var gFeedsPane = {
     window.addEventListener("unload", this, false);
   },
 
-//@line 177 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/preferences/feeds.js"
+//@line 177 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/preferences/feeds.js"
 
 
   /**
@@ -113,7 +113,7 @@ var gFeedsPane = {
     this.updateSelectedApplicationInfo();
 
     var readersList = this.element("readers");
-//@line 208 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/preferences/feeds.js"
+//@line 208 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/preferences/feeds.js"
 
     // List of web handlers
     var wccr = 
@@ -133,8 +133,9 @@ var gFeedsPane = {
       row.setAttribute("webhandlerurl", handlers[i].uri);
 
       var uri = ios.newURI(handlers[i].uri, null, null);
-      row.setAttribute("image", uri.prePath + "/favicon.ico");
-      
+      if (/^https?/.test(uri.scheme))
+        row.setAttribute("image", uri.prePath + "/favicon.ico");
+
       readersList.appendChild(row);
     }
   },
@@ -200,7 +201,7 @@ var gFeedsPane = {
         this._silentSelectReader(this.element("liveBookmarksListItem"));
         break;
       case "client":
-//@line 307 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/preferences/feeds.js"
+//@line 308 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/preferences/feeds.js"
 
         this._silentSelectReader(this.element("selectedApplicationListitem"));
         break;
@@ -295,7 +296,7 @@ var gFeedsPane = {
           // PREF_SELECTED_APP is saved in chooseClientApp
           this.element(PREF_SELECTED_READER).value = "client";
           break;
-//@line 407 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/preferences/feeds.js"
+//@line 408 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/preferences/feeds.js"
       }
     }
   }
