@@ -1,4 +1,4 @@
-//@line 37 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/preferences/security.js"
+//@line 38 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/preferences/security.js"
 
 var gSecurityPane = {
   _pane: null,
@@ -94,14 +94,13 @@ var gSecurityPane = {
   readCheckPhish: function ()
   {
     var phishEnabled = document.getElementById("browser.safebrowsing.enabled").value;
-    var remoteLookup = document.getElementById("browser.safebrowsing.remoteLookups").value;
 
     var checkPhish = document.getElementById("checkPhishChoice");
     var loadList = document.getElementById("onloadProvider");
     var onloadAfter = document.getElementById("onloadAfter");
 
     checkPhish.disabled = onloadAfter.disabled = !phishEnabled;
-    loadList.disabled = !phishEnabled || !remoteLookup;
+    loadList.disabled = !phishEnabled;
 
     // don't override pref value
     return undefined;
@@ -124,11 +123,15 @@ var gSecurityPane = {
     const prefName = "browser.safebrowsing.provider." +
                      providerNum +
                      ".privacy.optedIn";
-    var pref = document.createElement("preference");
-    pref.setAttribute("type", "bool");
-    pref.id = prefName;
-    pref.setAttribute("name", prefName);
-    document.getElementById("securityPreferences").appendChild(pref);
+    var pref = document.getElementById(prefName);
+
+    if (!pref) {
+      pref = document.createElement("preference");
+      pref.setAttribute("type", "bool");
+      pref.id = prefName;
+      pref.setAttribute("name", prefName);
+      document.getElementById("securityPreferences").appendChild(pref);
+    }
 
     // only show privacy policy if it hasn't already been shown or the user
     // hasn't agreed to it
@@ -148,24 +151,6 @@ var gSecurityPane = {
     return true;
   },
 
-  /**
-   * Enables and disables UI as necessary based on which type of phishing
-   * detection is currently selected (and whether phishing is even enabled,
-   * since this could trample on readCheckPhish during a preference update).
-   */
-  readPhishChoice: function ()
-  {
-    var phishPref = document.getElementById("browser.safebrowsing.enabled");
-    var phishChoice = document.getElementById("browser.safebrowsing.remoteLookups");
-
-    var onloadList = document.getElementById("onloadProvider");
-    if (phishPref.value)
-      onloadList.disabled = !phishChoice.value;
-
-    // don't override pref value
-    return undefined;
-  },
-
   /**
    * Displays a privacy policy if the user enables onload anti-phishing
    * checking. The policy must be accepted if onload checking is to be enabled,
@@ -187,6 +172,21 @@ var gSecurityPane = {
     return undefined;
   },
 
+  /**
+   * Ensures that the user has agreed to the selected provider's privacy policy
+   * if safe browsing is enabled.
+   */
+  onSBChange: function ()
+  {
+    var phishEnabled = document.getElementById("browser.safebrowsing.enabled").value;
+    var remoteLookup = document.getElementById("browser.safebrowsing.remoteLookups");
+    var providerNum = document.getElementById("onloadProvider").value;
+
+    if (phishEnabled && remoteLookup.value &&
+        !this._userAgreedToPhishingEULA(providerNum))
+      remoteLookup.value = false;
+  },
+
   /**
    * Populates the menulist of providers of cached phishing lists if the
    * menulist isn't already populated.
@@ -274,21 +274,9 @@ var gSecurityPane = {
   onProviderChanged: function ()
   {
     var pref = document.getElementById("browser.safebrowsing.dataProvider");
-    if (!this._userAgreedToPhishingEULA(pref.value)) {
-      this._disableOnloadPhishChecks();
-    }
-  },
-
-  /**
-   * Turns off onload phishing protection and updates UI accordingly.
-   */
-  _disableOnloadPhishChecks: function ()
-  {
     var remoteLookup = document.getElementById("browser.safebrowsing.remoteLookups");
-    remoteLookup.value = false;
 
-    var radio = document.getElementById("checkPhishChoice");
-    this._pane.userChangedValue(radio);
+    remoteLookup.value = this._userAgreedToPhishingEULA(pref.value);
   },
 
   // PASSWORDS
