@@ -1,4 +1,4 @@
-//@line 40 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 40 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
 
 const Cc = Components.classes;
 const Ci = Components.interfaces;
@@ -164,7 +164,7 @@ FeedWriter.prototype = {
     return this._selectedApplicationItemWrapped;
   },
 
-//@line 219 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 219 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
 
   /**
    * Writes the feed title into the preview document.
@@ -189,7 +189,7 @@ FeedWriter.prototype = {
    */
   _setTitleImage: function FW__setTitleImage(container) {
     try {
-      var parts = this._getPropertyAsBag(container, "image");
+      var parts = container.image;
       
       // Set up the title image (supplied by the feed)
       var feedTitleImage = this._document.getElementById("feedTitleImage");
@@ -234,7 +234,7 @@ FeedWriter.prototype = {
       var entryContainer = this._document.createElementNS(HTML_NS, "div");
       entryContainer.className = "entry";
 
-      // If the entry has a title, make it a like
+      // If the entry has a title, make it a link
       if (entry.title) {
         var a = this._document.createElementNS(HTML_NS, "a");
         a.appendChild(this._document.createTextNode(entry.title.plainText()));
@@ -248,7 +248,7 @@ FeedWriter.prototype = {
         entryContainer.appendChild(title);
       }
 
-      var body = this._document.createElementNS(HTML_NS, "p");
+      var body = this._document.createElementNS(HTML_NS, "div");
       var summary = entry.summary || entry.content;
       var docFragment = null;
       if (summary) {
@@ -258,7 +258,8 @@ FeedWriter.prototype = {
         else
           LOG("no base?");
         docFragment = summary.createDocumentFragment(body);
-        body.appendChild(docFragment);
+        if (docFragment)
+          body.appendChild(docFragment);
 
         // If the entry doesn't have a title, append a # permalink
         // See http://scripting.com/rss.xml for an example
@@ -274,6 +275,9 @@ FeedWriter.prototype = {
       body.className = "feedEntryContent";
       entryContainer.appendChild(body);
       feedContent.appendChild(entryContainer);
+      var clearDiv = this._document.createElementNS(HTML_NS, "div");
+      clearDiv.style.clear = "both";
+      feedContent.appendChild(clearDiv);
     }
   },
   
@@ -326,7 +330,7 @@ FeedWriter.prototype = {
    * @returns The display name of the application represented by the file.
    */
   _getFileDisplayName: function FW__getFileDisplayName(file) {
-//@line 398 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 402 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
     var ios = 
         Cc["@mozilla.org/network/io-service;1"].
         getService(Ci.nsIIOService);
@@ -387,9 +391,9 @@ FeedWriter.prototype = {
           // XXXben - we need to compare this with the running instance executable
           //          just don't know how to do that via script...
           // XXXmano TBD: can probably add this to nsIShellService
-//@line 464 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 468 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
           if (fp.file.leafName != "firefox-bin") {
-//@line 467 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 471 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
             var selectedAppMenuItem = this.selectedApplicationItemWrapped;
             this._initMenuItemWithFile(selectedAppMenuItem, selectedApp);
 
@@ -526,7 +530,7 @@ FeedWriter.prototype = {
             selectedAppMenuItem.hidden = false;
             selectedAppMenuItem.doCommand();
 
-//@line 612 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 616 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
             break;
           }
         }
@@ -576,7 +580,7 @@ FeedWriter.prototype = {
       selectedApplicationItem.hidden = true;
     }
 
-//@line 707 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 711 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
 
     // "Choose Application..." menuitem
     menuItem = this._document.createElementNS(XUL_NS, "menuitem");
@@ -618,7 +622,7 @@ FeedWriter.prototype = {
         // For privacy reasons we cannot set the image attribute directly
         // to the icon url, see Bug 358878
         var uri = makeURI(handlers[i].uri);
-        if (uri) 
+        if (uri && /^https?/.test(uri.scheme))
           new iconDataURIGenerator(uri.prePath + "/favicon.ico", menuItem)
       }
     }
@@ -793,7 +797,7 @@ FeedWriter.prototype = {
           prefs.setComplexValue(PREF_SELECTED_APP, Ci.nsILocalFile, 
                                 this.selectedApplicationItemWrapped.file);
           break;
-//@line 930 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 934 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
         case "liveBookmarksMenuItem":
           defaultHandler = "bookmarks";
           prefs.setCharPref(PREF_SELECTED_READER, "bookmarks");
@@ -872,41 +876,6 @@ FeedWriter.prototype = {
   }
 };
 
-
-// copied over from nsSearchService.js
-function b64(aBytes) {
-  const B64_CHARS =
-            "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
-  var out = "", bits, i, j;
-
-  while (aBytes.length >= 3) {
-    bits = 0;
-    for (i = 0; i < 3; i++) {
-      bits <<= 8;
-      bits |= aBytes[i];
-    }
-    for (j = 18; j >= 0; j -= 6)
-      out += B64_CHARS[(bits>>j) & 0x3F];
-
-    aBytes.splice(0, 3);
-  }
-
-  switch (aBytes.length) {
-    case 2:
-      out += B64_CHARS[(aBytes[0]>>2) & 0x3F];
-      out += B64_CHARS[((aBytes[0] & 0x03) << 4) | ((aBytes[1] >> 4) & 0x0F)];
-      out += B64_CHARS[((aBytes[1] & 0x0F) << 2)];
-      out += "=";
-      break;
-    case 1:
-      out += B64_CHARS[(aBytes[0]>>2) & 0x3F];
-      out += B64_CHARS[(aBytes[0] & 0x03) << 4];
-      out += "==";
-      break;
-  }
-  return out;
-}
-
 function iconDataURIGenerator(aURISpec, aElement) {
   var ios = Cc["@mozilla.org/network/io-service;1"].
             getService(Ci.nsIIOService);
@@ -953,13 +922,15 @@ iconDataURIGenerator.prototype = {
       requestFailed = !aRequest.requestSucceeded;
 
     if (!requestFailed && this._countRead != 0) {
+      var str = String.fromCharCode.apply(null, this._bytes);
       try {
-        var dataURI = ICON_DATAURL_PREFIX + b64(this._bytes);
+        var dataURI = ICON_DATAURL_PREFIX +
+                      this._element.ownerDocument.defaultView.btoa(str);
         this._element.setAttribute("src", dataURI);
         if (this._element.getAttribute("selected") == "true")
           this._element.parentNode.parentNode.setAttribute("src", dataURI);
       }
-      catch(ex) { }
+      catch(ex) {}
     }
     this._channel = null;
     this._element  = null;
@@ -1058,7 +1029,7 @@ function NSGetModule(cm, file) {
   return Module;
 }
 
-//@line 44 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
+//@line 44 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
 
 var gTraceOnAssert = true;
 
@@ -1085,12 +1056,12 @@ function NS_ASSERT(condition, message) {
 
   var assertionText = "ASSERT: " + message + "\n";
 
-//@line 72 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
+//@line 72 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
   Components.util.reportError(assertionText);
   return;
-//@line 108 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
+//@line 108 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
 }
-//@line 37 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/GenericFactory.js"
+//@line 37 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/GenericFactory.js"
 
 /**
  * An object implementing nsIFactory that can construct other objects upon
