@@ -1,4 +1,4 @@
-//@line 38 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/WebContentConverter.js"
+//@line 38 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/WebContentConverter.js"
 
 const Cc = Components.classes;
 const Ci = Components.interfaces;
@@ -24,6 +24,9 @@ const PREF_SELECTED_WEB = "browser.feeds.handlers.webservice";
 const PREF_SELECTED_ACTION = "browser.feeds.handler";
 const PREF_SELECTED_READER = "browser.feeds.handler.default";
 
+const NS_ERROR_MODULE_DOM = 2152923136;
+const NS_ERROR_DOM_SYNTAX_ERR = NS_ERROR_MODULE_DOM + 12;
+
 function WebContentConverter() {
 }
 WebContentConverter.prototype = {
@@ -340,7 +343,7 @@ var WebContentConverterRegistrar = {
    */
   registerProtocolHandler: 
   function WCCR_registerProtocolHandler(protocol, uriString, title, contentWindow) {
-//@line 390 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/WebContentConverter.js"
+//@line 393 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/WebContentConverter.js"
   },
 
   /**
@@ -355,8 +358,14 @@ var WebContentConverterRegistrar = {
 
     try {
       var uri = this._makeURI(uriString);
+    } catch (ex) {
+      // not supposed to throw according to spec
+      return; 
     }
-    catch(ex) { return; }
+
+    // If the uri doesn't contain '%s', it won't be a good content handler
+    if (uri.spec.indexOf("%s") < 0)
+      throw NS_ERROR_DOM_SYNTAX_ERR;
 
     // For security reasons we reject non-http(s) urls (see bug Bug 354316),
     // we may need to revise this once we support more content types
@@ -364,6 +373,8 @@ var WebContentConverterRegistrar = {
       throw("Permission denied to add " + uri.spec + "as a content handler");
 
     // XXXben - for Firefox 2 we only support feed types
+    // XXX this should be a "security exception" according to spec, but that
+    // isn't defined yet.
     contentType = this._resolveContentType(contentType);
     if (contentType != TYPE_MAYBE_FEED)
       return;    
@@ -718,7 +729,7 @@ function NSGetModule(cm, file) {
   return Module;
 }
 
-//@line 44 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
+//@line 44 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
 
 var gTraceOnAssert = true;
 
@@ -745,8 +756,8 @@ function NS_ASSERT(condition, message) {
 
   var assertionText = "ASSERT: " + message + "\n";
 
-//@line 72 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
+//@line 72 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
   Components.util.reportError(assertionText);
   return;
-//@line 108 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
+//@line 108 "/builds/tinderbox/Fx-Mozilla1.8-Nightly/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
 }
