@@ -49,6 +49,7 @@ const nsIDOMChromeWindow     = Components.interfaces.nsIDOMChromeWindow;
 const nsIDOMWindow           = Components.interfaces.nsIDOMWindow;
 const nsIFactory             = Components.interfaces.nsIFactory;
 const nsIFileURL             = Components.interfaces.nsIFileURL;
+const nsIJARURI              = Components.interfaces.nsIJARURI;
 const nsIHttpProtocolHandler = Components.interfaces.nsIHttpProtocolHandler;
 const nsIInterfaceRequestor  = Components.interfaces.nsIInterfaceRequestor;
 const nsIPrefBranch          = Components.interfaces.nsIPrefBranch;
@@ -61,6 +62,7 @@ const nsIWindowWatcher       = Components.interfaces.nsIWindowWatcher;
 const nsICategoryManager     = Components.interfaces.nsICategoryManager;
 const nsIWebNavigationInfo   = Components.interfaces.nsIWebNavigationInfo;
 const nsIBrowserSearchService = Components.interfaces.nsIBrowserSearchService;
+const nsICommandLineValidator = Components.interfaces.nsICommandLineValidator;
 
 const NS_BINDING_ABORTED = 0x804b0002;
 const NS_ERROR_WONT_HANDLE_CONTENT = 0x805d0001;
@@ -106,28 +108,69 @@ function resolveURIInternal(aCmdLine, aArgument) {
   return uri;
 }
 
+const OVERRIDE_NONE        = 0;
+const OVERRIDE_NEW_PROFILE = 1;
+const OVERRIDE_NEW_MSTONE  = 2;
+/**
+ * Determines whether a home page override is needed.
+ * Returns:
+ *  OVERRIDE_NEW_PROFILE if this is the first run with a new profile.
+ *  OVERRIDE_NEW_MSTONE if this is the first run with a build with a different
+ *                      Gecko milestone (i.e. right after an upgrade).
+ *  OVERRIDE_NONE otherwise.
+ */
 function needHomepageOverride(prefb) {
-  var savedmstone;
+  var savedmstone = null;
   try {
     savedmstone = prefb.getCharPref("browser.startup.homepage_override.mstone");
-  }
-  catch (e) {
-  }
+  } catch (e) {}
 
   if (savedmstone == "ignore")
-    return 0;
+    return OVERRIDE_NONE;
 
   var mstone = Components.classes["@mozilla.org/network/protocol;1?name=http"]
                          .getService(nsIHttpProtocolHandler).misc;
 
   if (mstone != savedmstone) {
     prefb.setCharPref("browser.startup.homepage_override.mstone", mstone);
-    // Return 1 if true if the pref didn't exist (i.e. new profile) or 2 for an upgrade
-    return (savedmstone ? 2 : 1);
+    return (savedmstone ? OVERRIDE_NEW_MSTONE : OVERRIDE_NEW_PROFILE);
+  }
+
+  return OVERRIDE_NONE;
+}
+
+// Copies a pref override file into the user's profile pref-override folder,
+// and then tells the pref service to reload it's default prefs.
+function copyPrefOverride() {
+  try {
+    var fileLocator = Components.classes["@mozilla.org/file/directory_service;1"]
+                                .getService(Components.interfaces.nsIProperties);
+    const NS_APP_EXISTING_PREF_OVERRIDE = "ExistingPrefOverride";
+    var prefOverride = fileLocator.get(NS_APP_EXISTING_PREF_OVERRIDE,
+                                       Components.interfaces.nsIFile);
+    if (!prefOverride.exists())
+      return; // nothing to do
+
+    const NS_APP_PREFS_OVERRIDE_DIR     = "PrefDOverride";
+    var prefOverridesDir = fileLocator.get(NS_APP_PREFS_OVERRIDE_DIR,
+                                           Components.interfaces.nsIFile);
+
+    // Check for any existing pref overrides, and remove them if present
+    var existingPrefOverridesFile = prefOverridesDir.clone();
+    existingPrefOverridesFile.append(prefOverride.leafName);
+    if (existingPrefOverridesFile.exists())
+      existingPrefOverridesFile.remove(false);
+
+    prefOverride.copyTo(prefOverridesDir, null);
+
+    // Now that we've installed the new-profile pref override file,
+    // re-read the default prefs.
+    var prefSvcObs = Components.classes["@mozilla.org/preferences-service;1"]
+                               .getService(Components.interfaces.nsIObserver);
+    prefSvcObs.observe(null, "reload-default-prefs", null);
+  } catch (ex) {
+    Components.utils.reportError(ex);
   }
-  
-  // Return 0 if not a new profile and not an upgrade
-  return 0;
 }
 
 function openWindow(parent, url, target, features, args) {
@@ -161,14 +204,14 @@ function getMostRecentWindow(aType) {
   return wm.getMostRecentWindow(aType);
 }
 
-//@line 169 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 215 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
 
 // this returns the most recent non-popup browser window
 function getMostRecentBrowserWindow() {
   var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
                      .getService(Components.interfaces.nsIWindowMediator);
 
-//@line 176 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 222 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
   var win = wm.getMostRecentWindow("navigator:browser", true);
 
   // if we're lucky, this isn't a popup, and we can just return this
@@ -181,7 +224,7 @@ function getMostRecentBrowserWindow() {
         win = nextWin;
     }
   }
-//@line 201 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 247 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
 
   return win;
 }
@@ -241,6 +284,7 @@ var nsBrowserContentHandler = {
         !iid.equals(nsICommandLineHandler) &&
         !iid.equals(nsIBrowserHandler) &&
         !iid.equals(nsIContentHandler) &&
+        !iid.equals(nsICommandLineValidator) &&
         !iid.equals(nsIFactory))
       throw Components.errors.NS_ERROR_NO_INTERFACE;
 
@@ -266,14 +310,17 @@ var nsBrowserContentHandler = {
     if (remoteCommand != null) {
       try {
         var a = /^\s*(\w+)\(([^\)]*)\)\s*$/.exec(remoteCommand);
-        var remoteVerb = a[1].toLowerCase();
-        var remoteParams = [];
-        var sepIndex = a[2].lastIndexOf(",");
-        if (sepIndex == -1)
-          remoteParams[0] = a[2];
-        else {
-          remoteParams[0] = a[2].substring(0, sepIndex);
-          remoteParams[1] = a[2].substring(sepIndex + 1);
+        var remoteVerb;
+        if (a) {
+          remoteVerb = a[1].toLowerCase();
+          var remoteParams = [];
+          var sepIndex = a[2].lastIndexOf(",");
+          if (sepIndex == -1)
+            remoteParams[0] = a[2];
+          else {
+            remoteParams[0] = a[2].substring(0, sepIndex);
+            remoteParams[1] = a[2].substring(sepIndex + 1);
+          }
         }
 
         switch (remoteVerb) {
@@ -283,15 +330,26 @@ var nsBrowserContentHandler = {
           // openURL(<url>,new-window)
           // openURL(<url>,new-tab)
 
-          var uri = resolveURIInternal(cmdLine, remoteParams[0]);
+          // First param is the URL, second param (if present) is the "target"
+          // (tab, window)
+          var url = remoteParams[0];
+          var target = nsIBrowserDOMWindow.OPEN_DEFAULTWINDOW;
+          if (remoteParams[1]) {
+            var targetParam = remoteParams[1].toLowerCase()
+                                             .replace(/^\s*|\s*$/g, "");
+            if (targetParam == "new-tab")
+              target = nsIBrowserDOMWindow.OPEN_NEWTAB;
+            else if (targetParam == "new-window")
+              target = nsIBrowserDOMWindow.OPEN_NEWWINDOW;
+            else {
+              // The "target" param isn't one of our supported values, so
+              // assume it's part of a URL that contains commas.
+              url += "," + remoteParams[1];
+            }
+          }
 
-          var location = nsIBrowserDOMWindow.OPEN_DEFAULTWINDOW;
-          if (/new-window/.test(remoteParams[1]))
-            location = nsIBrowserDOMWindow.OPEN_NEWWINDOW;
-          else if (/new-tab/.test(remoteParams[1]))
-            location = nsIBrowserDOMWindow.OPEN_NEWTAB;
-
-          handURIToExistingBrowser(uri, location, cmdLine);
+          var uri = resolveURIInternal(cmdLine, url);
+          handURIToExistingBrowser(uri, target, cmdLine);
           break;
 
         case "xfedocommand":
@@ -307,12 +365,13 @@ var nsBrowserContentHandler = {
         default:
           // Somebody sent us a remote command we don't know how to process:
           // just abort.
-          throw NS_ERROR_ABORT;
+          throw "Unknown remote command.";
         }
 
         cmdLine.preventDefault = true;
       }
       catch (e) {
+        Components.utils.reportError(e);
         // If we had a -remote flag but failed to process it, throw
         // NS_ERROR_ABORT so that the xremote code knows to return a failure
         // back to the handling code.
@@ -353,12 +412,28 @@ var nsBrowserContentHandler = {
       // Handle the old preference dialog URL separately (bug 285416)
       if (chromeParam == "chrome://browser/content/pref/pref.xul") {
         openPreferences();
-      } else {
-        var features = "chrome,dialog=no,all" + this.getFeatures(cmdLine);
-        openWindow(null, chromeParam, "_blank", features, "");
-      }
+        cmdLine.preventDefault = true;
+      } else try {
+        // only load URIs which do not inherit chrome privs.
 
-      cmdLine.preventDefault = true;
+        // normally would call checkLoadURI(..., DISALLOW_SCRIPT_OR_DATA)
+        // for this, but in this context we crash when the security manager
+        // tries to throw an exception (no window object here). On the branch
+        // we need to simulate the important bits
+        var uri = resolveURIInternal(cmdLine, chromeParam);
+        while (uri instanceof nsIJARURI) {
+          // unpack to find the real scheme
+          uri = uri.JARFile;
+        }
+        if (!uri.schemeIs("javascript") && !uri.schemeIs("data")) {
+          var features = "chrome,dialog=no,all" + this.getFeatures(cmdLine);
+          openWindow(null, uri.spec, "_blank", features, "");
+          cmdLine.preventDefault = true;
+        }
+      }
+      catch (e) {
+        Components.utils.reportError(e);
+      }
     }
     if (cmdLine.handleFlag("preferences", false)) {
       openPreferences();
@@ -373,7 +448,7 @@ var nsBrowserContentHandler = {
       cmdLine.preventDefault = true;
     }
 
-//@line 405 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 483 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
   },
 
   helpInfo : "  -browser            Open a browser window.\n",
@@ -386,39 +461,53 @@ var nsBrowserContentHandler = {
     var formatter = Components.classes["@mozilla.org/toolkit/URLFormatterService;1"]
                               .getService(Components.interfaces.nsIURLFormatter);
 
-    var pagesToLoad = "";
-    var overrideState = needHomepageOverride(prefb);
+    var overridePage = "";
+    var haveUpdateSession = false;
     try {
-      if (overrideState == 1) {
-        pagesToLoad = formatter.formatURLPref("startup.homepage_welcome_url");
-      }
-      else if (overrideState == 2) {
-        pagesToLoad = formatter.formatURLPref("startup.homepage_override_url");
-      }
-    }
-    catch (e) {
-    }
+      switch (needHomepageOverride(prefb)) {
+        case OVERRIDE_NEW_PROFILE:
+          // New profile.
+          overridePage = formatter.formatURLPref("startup.homepage_welcome_url");
+          break;
+        case OVERRIDE_NEW_MSTONE:
+          // Existing profile.
+          copyPrefOverride();
 
-    var startpage = "";
+          // Check whether we have a session to restore. If we do, we assume
+          // that this is an "update" session.
+          var ss = Components.classes["@mozilla.org/browser/sessionstartup;1"]
+                             .getService(Components.interfaces.nsISessionStartup);
+          haveUpdateSession = ss.doRestore();
+          overridePage = formatter.formatURLPref("startup.homepage_override_url");
+          break;
+      }
+    } catch (e) {}
+
+    // formatURLPref might return "about:blank" if getting the pref fails
+    if (overridePage == "about:blank")
+      overridePage = "";
+
+    var startPage = "";
     try {
       var choice = prefb.getIntPref("browser.startup.page");
       if (choice == 1)
-        startpage = this.startPage;
+        startPage = this.startPage;
 
       if (choice == 2)
-        startpage = Components.classes["@mozilla.org/browser/global-history;2"]
+        startPage = Components.classes["@mozilla.org/browser/global-history;2"]
                               .getService(nsIBrowserHistory).lastPageVisited;
-    }
-    catch (e) {
+    } catch (e) {
+      Components.utils.reportError(e);
     }
 
-    if (startpage == "about:blank")
-      startpage = "";
+    if (startPage == "about:blank")
+      startPage = "";
 
-    if (pagesToLoad && startpage) pagesToLoad += "|";
-    pagesToLoad += startpage;
-
-    return (pagesToLoad ?  pagesToLoad : "about:blank");
+    // Only show the startPage if we're not restoring an update session.
+    if (overridePage && startPage && !haveUpdateSession)
+      return overridePage + "|" + startPage;
+ 
+    return overridePage || startPage || "about:blank";
   },
 
   get startPage() {
@@ -503,6 +592,21 @@ var nsBrowserContentHandler = {
     request.cancel(NS_BINDING_ABORTED);
   },
 
+  /* nsICommandLineValidator */
+  validate : function bch_validate(cmdLine) {
+    // Other handlers may use osint so only handle the osint flag if the url
+    // flag is also present and the command line is valid.
+    var osintFlagIdx = cmdLine.findFlag("osint", false);
+    var urlFlagIdx = cmdLine.findFlag("url", false);
+    if (urlFlagIdx > -1 && (osintFlagIdx > -1 ||
+        cmdLine.state == nsICommandLine.STATE_REMOTE_EXPLICIT)) {
+      var urlParam = cmdLine.getArgument(urlFlagIdx + 1);
+      if (cmdLine.length != urlFlagIdx + 2 || /firefoxurl:/.test(urlParam))
+        throw NS_ERROR_ABORT;
+      cmdLine.handleFlag("osint", false)
+    }
+  },
+
   /* nsIFactory */
   createInstance: function bch_CI(outer, iid) {
     if (outer != null)
@@ -556,23 +660,49 @@ var nsDefaultCommandLineHandler = {
     return this;
   },
 
+  // List of uri's that were passed via the command line without the app
+  // running and have already been handled. This is compared against uri's
+  // opened using DDE on Win32 so we only open one of the requests.
+  _handledURIs: [ ],
+//@line 701 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
+
   /* nsICommandLineHandler */
   handle : function dch_handle(cmdLine) {
     var urilist = [];
 
+//@line 727 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
+
     try {
       var ar;
       while ((ar = cmdLine.handleFlagWithParam("url", false))) {
-        urilist.push(resolveURIInternal(cmdLine, ar));
+        var found = false;
+        var uri = resolveURIInternal(cmdLine, ar);
+        // count will never be greater than zero except on Win32.
+        var count = this._handledURIs.length;
+        for (var i = 0; i < count; ++i) {
+          if (this._handledURIs[i].spec == uri.spec) {
+            this._handledURIs.splice(i, 1);
+            found = true;
+            cmdLine.preventDefault = true;
+            break;
+          }
+        }
+        if (!found) {
+          urilist.push(uri);
+          // The requestpending command line flag is only used on Win32.
+          if (cmdLine.handleFlag("requestpending", false) &&
+              cmdLine.state == nsICommandLine.STATE_INITIAL_LAUNCH)
+            this._handledURIs.push(uri)
+        }
       }
     }
     catch (e) {
       Components.utils.reportError(e);
     }
 
-    var count = cmdLine.length;
+    count = cmdLine.length;
 
-    for (var i = 0; i < count; ++i) {
+    for (i = 0; i < count; ++i) {
       var curarg = cmdLine.getArgument(i);
       if (curarg.match(/^-/)) {
         Components.utils.reportError("Warning: unrecognized command line flag " + curarg + "\n");
@@ -603,7 +733,7 @@ var nsDefaultCommandLineHandler = {
       }
 
       var speclist = [];
-      for (var uri in urilist) {
+      for (uri in urilist) {
         if (shouldLoadURI(urilist[uri]))
           speclist.push(urilist[uri].spec);
       }
@@ -690,9 +820,9 @@ var Module = {
 
     registerType("text/html");
     registerType("application/vnd.mozilla.xul+xml");
-//@line 722 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 877 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
     registerType("image/svg+xml");
-//@line 724 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 879 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-53.EL_Depend/mozilla/browser/components/nsBrowserContentHandler.js"
     registerType("text/rdf");
     registerType("text/xml");
     registerType("application/xhtml+xml");
@@ -717,6 +847,9 @@ var Module = {
     catMan.addCategoryEntry("command-line-handler",
                             "x-default",
                             dch_contractID, true, true);
+    catMan.addCategoryEntry("command-line-validator",
+                            "b-browser",
+                            bch_contractID, true, true);
   },
     
   unregisterSelf : function mod_unregself(compMgr, location, type) {
@@ -731,6 +864,8 @@ var Module = {
                                "m-browser", true);
     catMan.deleteCategoryEntry("command-line-handler",
                                "x-default", true);
+    catMan.deleteCategoryEntry("command-line-validator",
+                               "b-browser", true);
   },
 
   canUnload: function(compMgr) {
